Index: /FCKeditor.Java/trunk/java-demo/src/main/webapp/jsp/sample01.jsp
===================================================================
--- /FCKeditor.Java/trunk/java-demo/src/main/webapp/jsp/sample01.jsp	(revision 2644)
+++ /FCKeditor.Java/trunk/java-demo/src/main/webapp/jsp/sample01.jsp	(revision 2645)
@@ -52,4 +52,5 @@
 			<li><FCK:check command="FileBrowsing" /></li>
 			<li><FCK:check command="FileUpload" /></li>
+			<li><FCK:check command="FolderCreation" /></li>
 		</ul>
 		<hr />

Index: /FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tags/CheckTag.java
===================================================================
--- /FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tags/CheckTag.java	(revision 2644)
+++ /FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tags/CheckTag.java	(revision 2645)
@@ -36,9 +36,8 @@
 
 /**
- * TODO Rework JavaDoc when ticket #2361
  * This tag displays information about browser and user capabilities. There are
  * tree available commands (CompatibleBrowser, FileBrowsing, FileUpload) which
  * respond an English message.<br />
  * <strong>Hint</strong>: The message string cannot be localized at the moment.
  * 
  * @version $Id$
@@ -50,10 +49,12 @@
 	private static final String FILE_UPLOAD = "FileUpload";
 	private static final String FILE_BROWSING = "FileBrowsing";
+	private static final String FOLDER_CREATION = "FolderCreation";
 	private static final String COMPATIBLE_BROWSER = "CompatibleBrowser";
-	private static Set<String> commands = new HashSet<String>(3);
+	private static Set<String> commands = new HashSet<String>(4);
 
 	static {
 		commands.add(FILE_UPLOAD);
 		commands.add(FILE_BROWSING);
+		commands.add(FOLDER_CREATION);
 		commands.add(COMPATIBLE_BROWSER);
 	}
@@ -63,4 +64,5 @@
 	/**
 	 * Sets the desired command.
+	 * 
 	 * @param command
 	 * @throws JspTagException
@@ -68,6 +70,7 @@
 	public void setCommand(String command) throws JspTagException {
 		if (!commands.contains(command))
-			throw new JspTagException("You have to provide one of the following commands: "
-			        + commands);
+			throw new JspTagException(
+					"You have to provide one of the following commands: "
+							+ commands);
 		this.command = command;
 	}
@@ -77,6 +80,8 @@
 		JspWriter out = pageContext.getOut();
 
-		HttpServletRequest request = (HttpServletRequest) pageContext.getRequest();
-		LocalizedPropertiesLoader lpl = LocalizedPropertiesLoader.getInstance(request);
+		HttpServletRequest request = (HttpServletRequest) pageContext
+				.getRequest();
+		LocalizedPropertiesLoader lpl = LocalizedPropertiesLoader
+				.getInstance(request);
 		String response = null;
 
@@ -94,4 +99,12 @@
 				response = lpl.getFileBrowsingDisabled();
 		}
+
+		if (command.equals(FOLDER_CREATION)) {
+			if (RequestCycleHandler.isEnabledForFolderCreation(request))
+				response = lpl.getFolderCreationEnabled();
+			else
+				response = lpl.getFolderCreationDisabled();
+		}
+
 		if (command.equals(COMPATIBLE_BROWSER)) {
 			if (Compatibility.isCompatibleBrowser(request))
@@ -104,5 +117,6 @@
 			out.print(response);
 		} catch (IOException e) {
-			throw new JspException("Tag response could not be written to the user!",e);
+			throw new JspException(
+					"Tag response could not be written to the user!", e);
 		}
 
@@ -36,9 +36,8 @@
  * This tag displays information about browser and user capabilities. There are
- * tree available commands (CompatibleBrowser, FileBrowsing, FileUpload) which
- * respond an English message.<br />
- * <strong>Hint</strong>: The message string cannot be localized at the moment.
+ * four available commands (CompatibleBrowser, FileBrowsing, FileUpload,
+ * FolderCreation) which respond the ability status as a localized message, if
+ * provided.
  * 
  * @version $Id$